==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/modules.js <==
var modules =
[
    [ "Gaseous chemistry parameters for the", "group__at__gaseous__chemistry.html", "group__at__gaseous__chemistry" ],
    [ "At_imbrication", "group__at__imbrication.html", "group__at__imbrication" ],
    [ "At_main", "group__at__main.html", "group__at__main" ],
    [ "At_soil", "group__at__soil.html", "group__at__soil" ],
    [ "Aerosol chemistry parameters for the", "group__at__aerosol__chemistry.html", "group__at__aerosol__chemistry" ],
    [ "Module for Arbitrary Lagrangian Eulerian method (ALE)", "group__albase.html", "group__albase" ],
    [ "Flags specifying general boundary zone type", "group__boundary__zone__flags.html", "group__boundary__zone__flags" ],
    [ "Flags specifying general field attributes", "group__field__flags.html", "group__field__flags" ],
    [ "Flags specifying general function attributes", "group__function__flags.html", "group__function__flags" ],
    [ "Module for calculation options", "group__cs__nz__condensation.html", "group__cs__nz__condensation" ],
    [ "Module for calculation options", "group__cs__nz__tagmr.html", "group__cs__nz__tagmr" ],
    [ "Flags specifying general volume zone type", "group__volume__zone__flags.html", "group__volume__zone__flags" ],
    [ "Module for numerical constants", "group__cstnum.html", "group__cstnum" ],
    [ "Module for physical constants", "group__cstphy.html", "group__cstphy" ],
    [ "Module for dimensions", "group__dimens.html", "group__dimens" ],
    [ "Module for input/output", "group__entsor.html", "group__entsor" ],
    [ "Additional user files", "group__userfile.html", "group__userfile" ],
    [ "Output log", "group__log.html", "group__log" ],
    [ "Mesh Fortran structure, pointers to the C structure", "group__mesh.html", "group__mesh" ],
    [ "Module for variable numbering", "group__numvar.html", "group__numvar" ],
    [ "Module for calculation options", "group__optcal.html", "group__optcal" ],
    [ "Module for basic MPI and OpenMP parallelism-related values", "group__parall.html", "group__parall" ],
    [ "Module for definition of general parameters", "group__paramx.html", "group__paramx" ],
    [ "Module for periodicity flags", "group__period.html", "group__period" ],
    [ "Module for pointer variables", "group__pointer__variables.html", "group__pointer__variables" ],
    [ "Module for rotation zones (rotors)", "group__at__rotation.html", "group__at__rotation" ],
    [ "Module for turbomachinery computations", "group__at__turbomachinery.html", "group__at__turbomachinery" ],
    [ "Flags specifying metadata related to an", "group__cdo__advfield__flags.html", "group__cdo__advfield__flags" ],
    [ "Flags specifying the type of boundary conditions", "group__cdo__bc__flags.html", "group__cdo__bc__flags" ],
    [ "Interpolation flags for CDO", "group__cdo__field__interpolation.html", "group__cdo__field__interpolation" ],
    [ "Flags specifying metadata related to the", "group__cdo__property__flags.html", "group__cdo__property__flags" ],
    [ "Flags specifying metadata related to the", "group__cdo__property__type.html", "group__cdo__property__type" ],
    [ "Module for cooling towers constants", "group__ctincl.html", "group__ctincl" ],
    [ "Module for Lagrangian model", "group__lagran.html", "group__lagran" ],
    [ "Specific physics", "group__specific__physic.html", "group__specific__physic" ],
    [ "Source terms", "group__source__terms.html", "group__source__terms" ],
    [ "flags specifying metadata related to a cs_adjacency_t", "group__adjacency.html", "group__adjacency" ],
    [ "Flags specifying bad cells treatment", "group__bad__cells__flags.html", "group__bad__cells__flags" ],
    [ "General module for specific physics", "group__ppincl.html", "group__ppincl" ],
    [ "General module for specific physics containing common parameters", "group__ppppar.html", "group__ppppar" ],
    [ "Module for specific physics thermophysical data", "group__thermophysical.html", "group__thermophysical" ],
    [ "Module for Radiative transfer", "group__radiat.html", "group__radiat" ],
    [ "Field names", "group__field__names.html", "group__field__names" ],
    [ "Predefined function objects", "group__function__object__defaults.html", "group__function__object__defaults" ],
    [ "Field keywords", "group__field__keywords.html", "group__field__keywords" ],
    [ "DoF categories", "group___main.html", "group___main" ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/modules.js <==
var modules =
[
    [ "At_main", "group__at__main.html", "group__at__main" ],
    [ "Flags specifying general boundary zone type", "group__boundary__zone__flags.html", "group__boundary__zone__flags" ],
    [ "Flags specifying general field attributes", "group__field__flags.html", "group__field__flags" ],
    [ "Flags specifying general function attributes", "group__function__flags.html", "group__function__flags" ],
    [ "Homogeneous mixture modelling", "group__homogeneous__mixture.html", "group__homogeneous__mixture" ],
    [ "Flags specifying general volume zone type", "group__volume__zone__flags.html", "group__volume__zone__flags" ],
    [ "Module for numerical constants", "group__cstnum.html", "group__cstnum" ],
    [ "Module for physical constants", "group__cstphy.html", "group__cstphy" ],
    [ "Mesh Fortran structure, pointers to the C structure", "group__mesh.html", "group__mesh" ],
    [ "Module for calculation options", "group__optcal.html", "group__optcal" ],
    [ "Module for basic MPI and OpenMP parallelism-related values", "group__parall.html", "group__parall" ],
    [ "Module for pointer variables", "group__pointer__variables.html", "group__pointer__variables" ],
    [ "Flags specifying metadata related to an", "group__cdo__advfield__flags.html", "group__cdo__advfield__flags" ],
    [ "Flags specifying the type of boundary conditions", "group__cdo__bc__flags.html", "group__cdo__bc__flags" ],
    [ "Interpolation flags for CDO", "group__cdo__field__interpolation.html", "group__cdo__field__interpolation" ],
    [ "Flags specifying metadata related to the", "group__cdo__property__flags.html", "group__cdo__property__flags" ],
    [ "Flags specifying metadata related to the", "group__cdo__property__type.html", "group__cdo__property__type" ],
    [ "Pulverized coal combustiontransported variables", "group__coal__combustion__t__var.html", "group__coal__combustion__t__var" ],
    [ "Pulverized coal combustionstate variables", "group__coal__combustion__s__var.html", "group__coal__combustion__s__var" ],
    [ "Pulverized coal combustionalgebraic variables", "group__coal__combustion__a__var.html", "group__coal__combustion__a__var" ],
    [ "flags specifying metadata related to a cs_adjacency_t", "group__adjacency.html", "group__adjacency" ],
    [ "Flags specifying bad cells treatment", "group__bad__cells__flags.html", "group__bad__cells__flags" ],
    [ "General module for specific physics", "group__ppincl.html", "group__ppincl" ],
    [ "Field names", "group__field__names.html", "group__field__names" ],
    [ "Predefined function objects", "group__function__object__defaults.html", "group__function__object__defaults" ],
    [ "Field keywords", "group__field__keywords.html", "group__field__keywords" ],
    [ "DoF categories", "group___main.html", "group___main" ],
    [ "Scalar_params", "group__scalar__params.html", "group__scalar__params" ],
    [ "Compressible", "group__compressible.html", "group__compressible" ],
    [ "Coal_combustion_s_var_disp", "group__coal__combustion__s__var__disp.html", "group__coal__combustion__s__var__disp" ]
];
